/**
 * This API is used for the localization methods.
 * Accessed from the window at window.sas.vi.localization.
 */
export interface LocalizationApi {
    /**
     * @method
     * @description Returns the MomentJS format string based on locale.
     * @param [showTime=true] {boolean} Checks whether or not to include time (in 12 hour format).
     * @returns The localized date time format as a string.
     */
    getLocalizedDateTimeFormat(showTime?: boolean): string;
    /**
     * @method
     * @description Gets the application locale in BCP 47 format.
     * @returns The current application locale.
     */
    getLocale(): string;
    /**
     * @method
     * @description Gets the application display direction.
     * This is either "ltr" for left-to-right display locales, or "rtl" for right-to-left locales.
     * @returns The current application display direction.
     */
    getDirection(): "ltr" | "rtl";
    /**
     * Methods related to Solution content localization.
     */
    solution: SolutionLocalizationApi;
}
export interface SolutionLocalizationApi {
    /**
     * if {@link isEnabled}, returns the {@link SolutionLocalizationBundle} used to lookup translations.
     */
    getLocalizationBundle(): SolutionLocalizationBundle | undefined;
    /**
     * returns true if solution localization is enabled.
     * methods will return unmodified inputs if not enabled.
     * note that solution localization is disabled in the administration application.
     */
    isEnabled(): boolean;
    /**
     * returns the localized value for the given resource key, else, undefined.
     * @param resourceKey
     */
    getLocalizedResource(resourceKey: string): string | undefined;
    /**
     * localize a string using a resourceKey.
     * fallback to lookup by value if the resourceKey is not supplied/found.
     * mappings are defined by the contents of {@link getLocalizationBundle}
     * @param str string to localize
     * @param resourceKey a resource key used to lookup the localized value
     * @returns the localized string
     * @example
     * localize("red", "colours.red.txt") === "rouge"
     */
    localize(str: string, resourceKey?: string): string;
    /**
     * localize string properties of an object
     * properties are provided as a map of <propertyKey, resourceKey>, deep property keys are accepted.
     * {@link localize} is applied to each property with its given resourceKey.
     * @param obj source object to localize
     * @param props properties to localize and their resource keys
     * @returns the localized object
     * @example
     * localizeObject({ label: "red" }, { "label": "colours.red.txt" }) === { label: "rouge" }
     */
    localizeObject<T extends object>(obj: T, props: Record<string, string | undefined>): T;
    /**
     * localize a list of objects.
     * {@link localizeObject} is applied to each element in the list.
     * @param list objects to translate
     * @param getProps callback to return a map of properties and resource keys for the given list element
     * @returns the localized list
     * @example
     *  localizeList(
     *      [{ id: "red", label: "Red" }, { id: "blue", label: "Blue"} ],
     *      (item) => ({ "label": `colours.${item.id}.title` })
     *  ) === [{ id: "red", label: "Rouge" }, { id: "blue", label: "Bleu"} ]
     */
    localizeList<T extends object>(list: T[], getProps: (obj: T) => Record<string, string | undefined>): T[];
}
/**
 * Stores localized strings by key and value.
 * @example
 *  {
 *      bykey: {
 *          "colours.red.label": "rouge",
 *          "colours.blue.label": "bleu"
 *      },
 *      byValue: {
 *          "red": "rouge",
 *          "blue": "bleu"
 *      }
 *  }
 */
interface SolutionLocalizationBundle {
    byKey: Record<string, string>;
    byValue: Record<string, string>;
}
export {};
